/*
 * Copyright (C) 2015 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.dialer.app;

import android.content.Context;
import android.support.design.widget.CoordinatorLayout;
import android.support.design.widget.Snackbar.SnackbarLayout;
import android.util.AttributeSet;
import android.view.View;
import android.widget.FrameLayout;
import com.android.dialer.proguard.UsedByReflection;

/**
 * Implements custom behavior for the movement of the FAB in response to the Snackbar. Because we
 * are not using the design framework FloatingActionButton widget, we need to manually implement the
 * Material Design behavior of having the FAB translate upward and downward with the appearance and
 * disappearance of a Snackbar.
 */
@UsedByReflection(value = "dialtacts_activity.xml")
public class FloatingActionButtonBehavior extends CoordinatorLayout.Behavior<FrameLayout> {

  @UsedByReflection(value = "dialtacts_activity.xml")
  public FloatingActionButtonBehavior(Context context, AttributeSet attrs) {}

  @Override
  public boolean layoutDependsOn(CoordinatorLayout parent, FrameLayout child, View dependency) {
    return dependency instanceof SnackbarLayout;
  }

  @Override
  public boolean onDependentViewChanged(
      CoordinatorLayout parent, FrameLayout child, View dependency) {
    float translationY = Math.min(0, dependency.getTranslationY() - dependency.getHeight());
    child.setTranslationY(translationY);
    return true;
  }
}
